==> hlog-0.14.tar.gz: hlog-0.14/qso_impl.h <==
/*
 * Copyright (c) 2020 Josef 'Jeff' Sipek <jeffpc@josefsipek.net>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

#ifndef __QSO_IMPL_H
#define __QSO_IMPL_H

#include "qso.h"

/*
 * Set a part of the QSO.  This is a lower-level call that's meant to
 * simplify the ADIF parsing code.  The explict setters above should be used
 * instead whenever possible.
 */
extern int qso_set(struct qso *qso, enum qso_item what, char *str);

/*
 * Pack a QSO
 */
extern struct nvlist *qso_pack(const struct qso *qso);
extern struct buffer *qso_pack_cbor(const struct qso *qso);

/*
 * Unpack a QSO
 */
extern int qso_unpack(struct qso *qso, struct nvlist *nvl);
extern int qso_unpack_cbor(struct qso *qso, const void *buf, size_t len);

#endif

==> hlog-0.15-rc1.tar.gz: hlog-0.15-rc1/qso_impl.h <==
/*
 * Copyright (c) 2020 Josef 'Jeff' Sipek <jeffpc@josefsipek.net>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

#ifndef __QSO_IMPL_H
#define __QSO_IMPL_H

#include "qso.h"

/*
 * Pack a QSO
 */
extern struct nvlist *qso_pack(const struct qso *qso);
extern struct buffer *qso_pack_cbor(const struct qso *qso);

/*
 * Unpack a QSO
 */
extern int qso_unpack(struct qso *qso, struct nvlist *nvl);
extern int qso_unpack_permissive(struct qso *qso, struct nvlist *nvl);
extern int qso_unpack_cbor(struct qso *qso, const void *buf, size_t len);

/*
 * Prepare an empty nvlist
 */
extern struct nvlist *qso_init_entry_nvl(void);

#endif
